@@ -1,17 +1,15 @@
 /* 
- * Copyright (C) 2004 Georgy Yunaev tim@krasnogorsk.ru
+ * Copyright (C) 2004-2012 George Yunaev gyunaev@ulduzsoft.com
  *
  * This library is free software; you can redistribute it and/or modify it 
  * under the terms of the GNU Lesser General Public License as published by 
- * the Free Software Foundation; either version 2 of the License, or (at your 
+ * the Free Software Foundation; either version 3 of the License, or (at your 
  * option) any later version.
  *
  * This library is distributed in the hope that it will be useful, but WITHOUT 
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public 
  * License for more details.
- *
- * $Id: errors.c 2 2004-09-08 11:49:02Z gyunaev $
  */
 
 static const char * libirc_strerror[LIBIRC_ERR_MAX] = 
@@ -32,6 +30,11 @@ static const char * libirc_strerror[LIBIRC_ERR_MAX] =
 	"Timeout error",
 	"Could not open file",
 	"IRC session terminated",
+	"IPv6 not supported",
+	"SSL not supported",
+	"SSL initialization failed",
+	"SSL connection failed",
+	"SSL certificate verify failed",
 };
 
 
